pub fn derive_path(
repo: &Repository,
spec: &BranchSpec,
config: &DeriveConfig,
) -> Result<Path>Expand description
Derive a Toolpath Path from a single branch specification.
pub fn derive_path(
repo: &Repository,
spec: &BranchSpec,
config: &DeriveConfig,
) -> Result<Path>Derive a Toolpath Path from a single branch specification.