pub fn get_repo_uri(repo: &Repository, remote_name: &str) -> Result<String>Expand description
Get the repository URI from a remote, falling back to a file:// URI.
pub fn get_repo_uri(repo: &Repository, remote_name: &str) -> Result<String>Get the repository URI from a remote, falling back to a file:// URI.